@@ -1,18 +1,20 @@
 use super::*;
+use bytes::{Bytes, BytesMut};
 
 #[test]
-fn test_audio_level_extension_too_small() -> Result<(), Error> {
-    let raw = Bytes::from_static(&[]);
-    let result = AudioLevelExtension::unmarshal(&raw);
+fn test_audio_level_extension_too_small() -> Result<()> {
+    let mut buf = &vec![0u8; 0][..];
+    let result = AudioLevelExtension::unmarshal(&mut buf);
     assert!(result.is_err());
 
     Ok(())
 }
 
 #[test]
-fn test_audio_level_extension_voice_true() -> Result<(), Error> {
+fn test_audio_level_extension_voice_true() -> Result<()> {
     let raw = Bytes::from_static(&[0x88]);
-    let a1 = AudioLevelExtension::unmarshal(&raw)?;
+    let buf = &mut raw.clone();
+    let a1 = AudioLevelExtension::unmarshal(buf)?;
     let a2 = AudioLevelExtension {
         level: 8,
         voice: true,
@@ -27,9 +29,10 @@ fn test_audio_level_extension_voice_true() -> Result<(), Error> {
 }
 
 #[test]
-fn test_audio_level_extension_voice_false() -> Result<(), Error> {
+fn test_audio_level_extension_voice_false() -> Result<()> {
     let raw = Bytes::from_static(&[0x8]);
-    let a1 = AudioLevelExtension::unmarshal(&raw)?;
+    let buf = &mut raw.clone();
+    let a1 = AudioLevelExtension::unmarshal(buf)?;
     let a2 = AudioLevelExtension {
         level: 8,
         voice: false,
@@ -44,7 +47,7 @@ fn test_audio_level_extension_voice_false() -> Result<(), Error> {
 }
 
 #[test]
-fn test_audio_level_extension_level_overflow() -> Result<(), Error> {
+fn test_audio_level_extension_level_overflow() -> Result<()> {
     let a = AudioLevelExtension {
         level: 128,
         voice: false,
